import 'dart:developer';

import 'package:dio/dio.dart';
import 'package:pmd/data/mapper/house_mapper.dart';
import 'package:pmd/data/dtos/houses_dto.dart';
import 'package:pmd/models/card_data.dart';
import 'package:pmd/repositories/api_interface.dart';
import 'package:pretty_dio_logger/pretty_dio_logger.dart';


class PotterRepository extends ApiInterface {
  static final Dio _dio = Dio(
      BaseOptions(connectTimeout: Duration(seconds: 10)))
    ..interceptors.add(
        PrettyDioLogger(request: true, requestHeader: true, requestBody: true));

  static const String _baseUrl = "https://api.potterdb.com/v1"; // https://api.realtor.com/v1

  @override
  Future<List<CardData>?> loadData(String? q) async {
    try {
      const String url = '$_baseUrl/characters?page[size]=5';

      final Response<dynamic> response = await _dio.get<Map<dynamic, dynamic>>(
        url,
        queryParameters: q != null ? {"filter[name_cont]": q} : null,
      );

      final HousesDto dto =
          HousesDto.fromJson(response.data as Map<String, dynamic>);

      final List<CardData>? data = dto.data?.map((e) => e.toDomain()).toList();

      return data;
    } on DioException catch (e) {
      log("DioException: $e");
      return null;
    } catch (e) {
      log('Unknown error: $e');
      return null;
    }
  }
}
